"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const base_1 = require("../error/base");
const pg_1 = require("pg");
const db_service_1 = require("./db_service");
const db_1 = require("../error/db");
exports.DB_QUERY = 'DB_QUERY';
exports.NO_ROW_ERROR = 'DB_NO_SUCH_';
pg_1.defaults.parseInt8 = true;
class PgService {
    constructor(pgPool) {
        this.pool = pgPool;
    }
    async run(query, params) {
        return await this._run(query, params);
    }
    async getRows(query, params) {
        const items = await this._run(query, params);
        return items.rows;
    }
    async getRow(query, params) {
        const items = await this._run(query, params);
        const rows = items.rows || [];
        if (rows.length === 0) {
            return false;
        }
        if (rows.length > 1) {
            console.warn(db_service_1.ONE_ROW_WARNING, rows.length, query);
        }
        return rows[0];
    }
    async mustGetRow(errorCode, query, params) {
        const row = await this.getRow(query, params);
        if (row === false) {
            throw new db_1.DbError({
                code: errorCode,
                status: base_1.BaseError.CODE_NOT_FOUND,
                innerDetails: {}
            });
        }
        return row;
    }
    async _run(query, params = []) {
        try {
            return await this.pool.query(query, params);
        }
        catch (err) {
            throw new db_1.DbError({
                code: exports.DB_QUERY,
                innerDetails: err
            });
        }
    }
}
exports.PgService = PgService;
