"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const base_1 = require("../../error/base");
const auth_1 = require("../../error/auth");
async function errorMiddleware(ctx, next) {
    try {
        await next();
    }
    catch (err) {
        console.error('Error middleware caught an error:', err.toString());
        let error;
        if (err instanceof base_1.BaseError) {
            error = err;
        }
        else if (err.status === 401) {
            error = new auth_1.AuthError(auth_1.AuthError.TOKEN_IS_INVALID, process.env.NODE_ENV === 'development' ? ctx.request.headers : {});
        }
        else {
            error = new base_1.BaseError({
                innerDetails: err
            });
        }
        console.error('Error middleware mapped an error:', error.toString());
        ctx.status = error.status;
        const result = {
            error: error.code
        };
        result.details = error.details;
        ctx.body = result;
    }
}
exports.errorMiddleware = errorMiddleware;
