"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const cls_service_1 = require("../../services/cls_service");
const trace_1 = require("../../trace");
const X_B3_TRACE_ID_HEADER = 'X-B3-TraceId';
const X_B3_SPAN_ID_HEADER = 'X-B3-SpanId';
const X_B3_PARENT_SPAN_ID_HEADER = 'X-B3-ParentSpanId';
async function traceMiddleware(ctx, next) {
    const startTrace = new trace_1.Trace(ctx.req.headers[X_B3_TRACE_ID_HEADER], ctx.req.headers[X_B3_SPAN_ID_HEADER], ctx.req.headers[X_B3_PARENT_SPAN_ID_HEADER]);
    return await cls_service_1.ClsService.createCls(async () => {
        cls_service_1.ClsService.setTrace(startTrace);
        const result = await next();
        const endTrace = cls_service_1.ClsService.getTrace();
        ctx.set({
            [X_B3_TRACE_ID_HEADER]: endTrace.traceId,
            [X_B3_SPAN_ID_HEADER]: endTrace.spanId,
            [X_B3_PARENT_SPAN_ID_HEADER]: endTrace.parentSpanId
        });
        return result;
    });
}
exports.traceMiddleware = traceMiddleware;
